SockJS-cyclone
==============

.. image:: https://secure.travis-ci.org/flaviogrossi/sockjs-cyclone.png?branch=master
   :target: http://travis-ci.org/#!/flaviogrossi/sockjs-cyclone

SockJS-cyclone is a pure Python server implementation for the
`SockJS protocol <https://github.com/sockjs/sockjs-protocol>`_ (version 0.3) running on the
`Cyclone <http://cyclone.io>`_ web server.

Please note that this is a work-in-progress implementation.


Credits
=======
Thanks to:

- Serge S. Koval for the tornado implementation;

- Voismart s.r.l for sponsoring the project.

